# aprofs package metadada

![Alt text](./docs/logo.png)

## aprofs: Approximate Prediction Feature Selection using Shapley Values

Welcome to aprofs, an open-source Python package designed to simplify the process of feature selection using approximate prediction with Shapley values.

The idea is that using on this package you can speed up feature selection (in an approximate way).

Please look at the package website for more resources: [Aprofs Documentation](https://blewy.github.io/aprofs/)

## Features

- **Feature Selection**: aprofs uses Shapley values, a concept from cooperative game theory, to identify the most important features in your dataset.

- **Feature Visualization**: aprofs uses Shapley values to check the marginal behavior of the feature used by the model using pdp plots.

## Installation
You can install aprofs via pip:

```bash
pip install aprofs==0.0.3
```

## Usage
Please look into the website here: [Aprofs Documentation](https://blewy.github.io/aprofs/)

## Contributing
As an open-source project, we welcome contributions from the community. I will create a CONTRIBUTING.md for guidelines on how to contribute.

License
This project is licensed under the terms of the MIT license.
